@@ -1,4 +1,4 @@
-#!/bin/sh
+#!/bin/bash
 # libCStreamedXML/test.sh
 #
 #  (c)2009, Laurence Withers, <l@lwithers.me.uk>.
@@ -33,10 +33,10 @@ print_tests() {
     echo "---------------------------------------------------------------------"
     for EXE in obj/tests/*
     do
-        [ -x ${EXE} ] || continue
-        NAME=$(echo ${EXE} | sed 's,obj/tests/,,')
+        [ -x "${EXE}" ] || continue
+        NAME="$(echo "${EXE}" | sed 's,obj/tests/,,')"
         echo -ne "${NAME}\t"
-        LD_LIBRARY_PATH="obj" ${EXE} --print-summary
+        LD_LIBRARY_PATH="obj" "${EXE}" --print-summary
     done
 }
 
